@@ -15,6 +15,17 @@
 # specific language governing permissions and limitations
 # under the License.
 
+# BEGIN: eager-load interesting stdlib/default dependencies
+# We exclude from built artifacts the stdlib implementations of "default gems"
+# for which our bundle pins to a later version. Requiring them here ensures
+# that our build breaks if doing so excludes the ONLY implementation, which
+# would be possible if an updated JRuby includes a "default gem" that meets
+# the pin criteria.
+# SEE: https://github.com/elastic/logstash/pull/17659
+require 'cgi'
+require 'uri'
+# END: eager load
+
 require "logstash/environment"
 require "logstash/config/cpu_core_strategy"
 require "logstash/instrument/collector"
@@ -26,6 +37,7 @@ require "logstash/pipeline_action"
 require "logstash/state_resolver"
 require "logstash/pipelines_registry"
 require "logstash/persisted_queue_config_validator"
+require "logstash/pipeline_resource_usage_validator"
 require "stud/trap"
 require "uri"
 require "socket"
@@ -40,6 +52,8 @@ class LogStash::Agent
   attr_reader :metric, :name, :settings, :dispatcher, :ephemeral_id, :pipeline_bus
   attr_accessor :logger
 
+  attr_reader :health_observer
+
   # initialize method for LogStash::Agent
   # @param params [Hash] potential parameters are:
   #   :name [String] - identifier for the agent
@@ -51,6 +65,9 @@ class LogStash::Agent
     @auto_reload = setting("config.reload.automatic")
     @ephemeral_id = SecureRandom.uuid
 
+    java_import("org.logstash.health.HealthObserver")
+    @health_observer ||= HealthObserver.new
+
     # Mutex to synchronize in the exclusive method
     # Initial usage for the Ruby pipeline initialization which is not thread safe
     @webserver_control_lock = Mutex.new
@@ -97,6 +114,7 @@ class LogStash::Agent
     initialize_geoip_database_metrics(metric)
 
     @pq_config_validator = LogStash::PersistedQueueConfigValidator.new
+    @pipeline_resource_usage_validator = LogStash::PipelineResourceUsageValidator.new(Java::java.lang.Runtime.getRuntime().maxMemory)
 
     @dispatcher = LogStash::EventDispatcher.new(self)
     LogStash::PLUGIN_REGISTRY.hooks.register_emitter(self.class, dispatcher)
@@ -151,6 +169,31 @@ class LogStash::Agent
     transition_to_stopped
   end
 
+  include org.logstash.health.PipelineIndicator::PipelineDetailsProvider
+  def pipeline_details(pipeline_id)
+    logger.trace("fetching pipeline details for `#{pipeline_id}`")
+    pipeline_id = pipeline_id.to_sym
+
+    java_import org.logstash.health.PipelineIndicator
+
+    pipeline_state = @pipelines_registry.states.get(pipeline_id)
+    if pipeline_state.nil?
+      return PipelineIndicator::Details.new(PipelineIndicator::Status::UNKNOWN)
+    end
+
+    pipeline_state.synchronize do |sync_state|
+      status = case
+               when sync_state.loading?    then PipelineIndicator::Status::LOADING
+               when sync_state.crashed?    then PipelineIndicator::Status::TERMINATED
+               when sync_state.running?    then PipelineIndicator::Status::RUNNING
+               when sync_state.finished?   then PipelineIndicator::Status::FINISHED
+               else                             PipelineIndicator::Status::UNKNOWN
+               end
+
+      PipelineIndicator::Details.new(status, sync_state.pipeline&.to_java.collectWorkerUtilizationFlowObservation)
+    end
+  end
+
   def auto_reload?
     @auto_reload
   end
@@ -191,13 +234,15 @@ class LogStash::Agent
 
     converge_result = resolve_actions_and_converge_state(results.response)
     update_metrics(converge_result)
-
-    logger.info(
-        "Pipelines running",
-        :count => running_pipelines.size,
-        :running_pipelines => running_pipelines.keys,
-        :non_running_pipelines => non_running_pipelines.keys
-    ) if converge_result.success? && converge_result.total > 0
+    if converge_result.success? && converge_result.total > 0
+      logger.info(
+          "Pipelines running",
+          :count => running_pipelines.size,
+          :running_pipelines => running_pipelines.keys,
+          :non_running_pipelines => non_running_pipelines.keys
+      )
+      @pipeline_resource_usage_validator.check(@pipelines_registry)
+    end
 
     dispatch_events(converge_result)
 
@@ -395,7 +440,13 @@ class LogStash::Agent
             )
           end
         rescue SystemExit, Exception => e
-          logger.error("Failed to execute action", :action => action, :exception => e.class.name, :message => e.message, :backtrace => e.backtrace)
+          error_details = { :action => action, :exception => e.class.name, :message => e.message, :backtrace => e.backtrace }
+          cause = e.cause
+          if cause && e != cause
+            error_details[:cause] = { :exception => cause.class, :message => cause.message }
+            error_details[:cause][:backtrace] = cause.backtrace if cause.backtrace
+          end
+          logger.error('Failed to execute action', error_details)
           converge_result.add(action, LogStash::ConvergeResult::FailedAction.from_exception(e))
         end
       end
