@@ -15,7 +15,6 @@
 # specific language governing permissions and limitations
 # under the License.
 
-
 require "logstash/plugin"
 require "logstash/config/mixin"
 require "logstash/codecs/base"
@@ -69,7 +68,7 @@ class LogStash::Inputs::Base < LogStash::Plugin
   end
 
   public
-  def initialize(params={})
+  def initialize(params = {})
     super
     @threadable = false
     @stop_called = Concurrent::AtomicBoolean.new(false)
@@ -109,8 +108,8 @@ class LogStash::Inputs::Base < LogStash::Plugin
     @stop_called.value
   end
 
-  def clone
-    cloned = super
+  def clone(*args)
+    cloned = super(args)
     cloned.codec = @codec.clone if @codec
     cloned
   end
@@ -137,8 +136,8 @@ class LogStash::Inputs::Base < LogStash::Plugin
     # Only set 'type' if not already set. This is backwards-compatible behavior
     event.set("type", @type) if @type && !event.include?("type")
 
-    LogStash::Util::Decorators.add_fields(@add_field,event,"inputs/#{self.class.name}")
-    LogStash::Util::Decorators.add_tags(@tags,event,"inputs/#{self.class.name}")
+    LogStash::Util::Decorators.add_fields(@add_field, event, "inputs/#{self.class.name}")
+    LogStash::Util::Decorators.add_tags(@tags, event, "inputs/#{self.class.name}")
   end
 
   protected
