@@ -34,7 +34,6 @@ end
 require "clamp"
 require "logstash-core/logstash-core"
 require "logstash/environment"
-require "logstash/modules/cli_parser"
 require "logstash/util/settings_helper"
 require "logstash/util/jackson"
 
@@ -46,7 +45,6 @@ require "logstash/patches/clamp"
 require "logstash/settings"
 require "logstash/version"
 require 'logstash/plugins'
-require "logstash/modules/util"
 require "logstash/bootstrap_check/default_config"
 require 'logstash/deprecation_message'
 
@@ -92,31 +90,6 @@ class LogStash::Runner < Clamp::StrictCommand
          :default => LogStash::SETTINGS.get_default("config.field_reference.escape_style"),
          :attribute_name => "config.field_reference.escape_style"
 
-
-  # Module settings
-  option ["--modules"], "MODULES",
-    I18n.t("logstash.runner.flag.modules"),
-    :multivalued => true,
-    :attribute_name => "modules_list"
-
-  option ["-M", "--modules.variable"], "MODULES_VARIABLE",
-    I18n.t("logstash.runner.flag.modules_variable"),
-    :multivalued => true,
-    :attribute_name => "modules_variable_list"
-
-  option ["--setup"], :flag,
-    I18n.t("logstash.runner.flag.modules_setup"),
-    :default => LogStash::SETTINGS.get_default("modules_setup"),
-    :attribute_name => "modules_setup"
-
-  option ["--cloud.id"], "CLOUD_ID",
-    I18n.t("logstash.runner.flag.cloud_id"),
-    :attribute_name => "cloud.id"
-
-  option ["--cloud.auth"], "CLOUD_AUTH",
-    I18n.t("logstash.runner.flag.cloud_auth"),
-    :attribute_name => "cloud.auth"
-
   # Pipeline settings
   option ["--pipeline.id"], "ID",
     I18n.t("logstash.runner.flag.pipeline-id"),
@@ -251,27 +224,6 @@ class LogStash::Runner < Clamp::StrictCommand
     I18n.t("logstash.runner.flag.quiet"),
     :new_flag => "log.level", :new_value => "error"
 
-  deprecated_option ["--http.enabled"], :flag,
-    I18n.t("logstash.runner.flag.http_enabled"),
-    :new_flag => "api.enabled", :passthrough => true, # use settings to disambiguate
-    :obsoleted_version => "9"
-
-  deprecated_option ["--http.host"], "HTTP_HOST",
-    I18n.t("logstash.runner.flag.http_host"),
-    :new_flag => "api.http.host", :passthrough => true, # use settings to disambiguate
-    :obsoleted_version => "9"
-
-  deprecated_option ["--http.port"], "HTTP_PORT",
-    I18n.t("logstash.runner.flag.http_port"),
-    :new_flag => "api.http.port", :passthrough => true, # use settings to disambiguate
-    :obsoleted_version => "9"
-
-  deprecated_option ["--event_api.tags.illegal"], "STRING",
-         I18n.t("logstash.runner.flag.event_api.tags.illegal"),
-         :default => LogStash::SETTINGS.get_default("event_api.tags.illegal"),
-         :attribute_name => "event_api.tags.illegal", :passthrough => true,
-         :obsoleted_version => "9"
-
   # We configure the registry and load any plugin that can register hooks
   # with logstash, this needs to be done before any operation.
   SYSTEM_SETTINGS = LogStash::SETTINGS.clone
@@ -287,7 +239,6 @@ class LogStash::Runner < Clamp::StrictCommand
     # Default we check local sources: `-e`, `-f` and the logstash.yml options.
     @source_loader = LogStash::Config::SourceLoader.new(@settings)
     @source_loader.add_source(LogStash::Config::Source::Local.new(@settings))
-    @source_loader.add_source(LogStash::Config::Source::Modules.new(@settings))
     @source_loader.add_source(LogStash::Config::Source::MultiLocal.new(@settings))
 
     super(*args)
@@ -315,26 +266,18 @@ class LogStash::Runner < Clamp::StrictCommand
     if setting("config.debug") && !logger.debug?
       logger.warn("--config.debug was specified, but log.level was not set to \'debug\'! No config info will be logged.")
     end
-    if setting("pipeline.buffer.type") == nil
-      deprecation_logger.deprecated(
-        "'pipeline.buffer.type' setting is not explicitly defined."\
-        "Before moving to 9.x set it to 'heap' and tune heap size upward, or set it to 'direct' to maintain existing behavior."
-      )
-
-      # set to direct to keep backward ecs_compatibility
-      buffer_type_setting = @settings.get_setting("pipeline.buffer.type")
-      buffer_type_setting.set("direct")
+    if setting("pipeline.buffer.type") != nil
+      configure_pipeline_buffer_type
     end
-    configure_pipeline_buffer_type
+
+    deprecation_logger.deprecated "The setting `queue.checkpoint.interval` has no effect and will be removed from both " +
+          "logstash.yml and pipeline.yml in a future release." if @settings.set?("queue.checkpoint.interval")
 
     while (msg = LogStash::DeprecationMessage.instance.shift)
       deprecation_logger.deprecated msg
     end
 
-    if JavaVersion::CURRENT < JavaVersion::JAVA_11
-      logger.warn I18n.t("logstash.runner.java.version",
-                                             :java_home => java.lang.System.getProperty("java.home"))
-    elsif JavaVersion::CURRENT < JavaVersion::JAVA_17
+    if JavaVersion::CURRENT < JavaVersion::JAVA_17
       deprecation_logger.deprecated I18n.t("logstash.runner.java.version_17_minimum",
                                            :java_home => java.lang.System.getProperty("java.home"))
     end
@@ -350,8 +293,6 @@ class LogStash::Runner < Clamp::StrictCommand
     jvmArgs = ManagementFactory.getRuntimeMXBean().getInputArguments()
     logger.info "JVM bootstrap flags: #{jvmArgs}"
 
-    # Add local modules to the registry before everything else
-    LogStash::Modules::Util.register_local_modules(LogStash::Environment::LOGSTASH_HOME)
 
     # Verify the Jackson defaults
     LogStash::Util::Jackson.verify_jackson_overrides
@@ -370,18 +311,8 @@ class LogStash::Runner < Clamp::StrictCommand
     logger.debug("Setting global FieldReference escape style: #{field_reference_escape_style}")
     org.logstash.FieldReference::set_escape_style(field_reference_escape_style)
 
-    tags_illegal_setting = settings.get_setting('event_api.tags.illegal').value
-    if tags_illegal_setting == 'warn'
-      deprecation_logger.deprecated(I18n.t("logstash.runner.tags-illegal-warning"))
-      org.logstash.Event::set_illegal_tags_action(tags_illegal_setting)
-    end
-
     return start_shell(setting("interactive"), binding) if setting("interactive")
 
-    module_parser = LogStash::Modules::CLIParser.new(setting("modules_list"), setting("modules_variable_list"))
-    # Now populate Setting for modules.list with our parsed array.
-    @settings.set("modules.cli", module_parser.output)
-
     begin
       @bootstrap_checks.each { |bootstrap| bootstrap.check(@settings) }
     rescue LogStash::BootstrapCheckError => e
@@ -492,16 +423,12 @@ class LogStash::Runner < Clamp::StrictCommand
   end # def self.main
 
   def running_as_superuser
-    if Process.euid() == 0
-      unless @settings.set?("allow_superuser")
-        deprecation_logger.deprecated("Starting from version 9.0, " +
-          "running with superuser privileges is not permitted unless you explicitly set 'allow_superuser' to true, " +
-          "thereby acknowledging the possible security risks")
-      end
+    return if LogStash::Environment.windows? # windows euid always returns 0, skip checking
 
+    if Process.euid() == 0
       if setting("allow_superuser")
-        logger.warn("NOTICE: Running Logstash as a superuser is strongly discouraged as it poses a security risk. " +
-                      "Set 'allow_superuser' to false for better security.")
+        logger.warn("NOTICE: Allowing Logstash to run as superuser is heavily discouraged as it poses a security risk. " +
+                      "It is strongly recommended to set 'allow_superuser' to false.")
       else
         raise(RuntimeError, "Logstash cannot be run as superuser.")
       end
