@@ -66,7 +66,7 @@ module LogStash
       "pipeline.ordered",
       "pipeline.ecs_compatibility",
       "queue.checkpoint.acks",
-      "queue.checkpoint.interval",
+      "queue.checkpoint.interval", # remove it for #17155
       "queue.checkpoint.writes",
       "queue.checkpoint.retry",
       "queue.drain",
@@ -413,26 +413,7 @@ module LogStash
     ### Specific settings #####
 
     java_import org.logstash.settings.Boolean
-
-    class Numeric < Coercible
-      def initialize(name, default = nil, strict = true)
-        super(name, ::Numeric, default, strict)
-      end
-
-      def coerce(v)
-        return v if v.is_a?(::Numeric)
-
-        # I hate these "exceptions as control flow" idioms
-        # but Ruby's `"a".to_i => 0` makes it hard to do anything else.
-        coerced_value = (Integer(v) rescue nil) || (Float(v) rescue nil)
-
-        if coerced_value.nil?
-          raise ArgumentError.new("Failed to coerce value to Numeric. Received #{v} (#{v.class})")
-        else
-          coerced_value
-        end
-      end
-    end
+    java_import org.logstash.settings.SettingNumeric
 
     class Integer < Coercible
       def initialize(name, default = nil, strict = true)
@@ -783,30 +764,6 @@ module LogStash
       end
     end
 
-    class Modules < Coercible
-      def initialize(name, klass, default = nil)
-        super(name, klass, default, false)
-      end
-
-      def set(value)
-        coerced_value = coerce(value)
-        @wrapped_setting.set(coerced_value)
-        coerced_value
-      end
-
-      def coerce(value)
-        if value.is_a?(@klass)
-          return value
-        end
-        @klass.new(value)
-      end
-
-      protected
-      def validate(value)
-        coerce(value)
-      end
-    end
-
     java_import org.logstash.settings.NullableSetting
 
     # @see Setting#nullable
